#
# spec file for package python-pytest-services
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-services
Version:        2.2.1
Release:        3.5
Summary:        Services plugin for pytest testing framework
License:        MIT
URL:            https://github.com/pytest-dev/pytest-services
Source:         https://github.com/pytest-dev/pytest-services/archive/%{version}.tar.gz
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pylibmc}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zc.lockfile >= 2.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with python2}
BuildRequires:  python-subprocess32
%endif
Requires:       python-psutil
Requires:       python-pytest
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-zc.lockfile >= 2.0
Recommends:     python-pylibmc
BuildArch:      noarch
%ifpython2
Requires:       python-subprocess32
%endif
%python_subpackages

%description
The plugin provides a set of fixtures and utility functions to start service
processes for your tests with pytest.

%prep
%setup -q -n pytest-services-%{version}
# we don't test mysql anway
sed -i -e '/import MySQLdb/d' tests/test_plugin.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_memcached test_mysql test_xvfb - need running X/mysql/memcache servers
%pytest -k 'not (test_memcached or test_mysql or test_xvfb)'

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Mar 23 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove mock BuildRequires, not needed.
* Thu Nov  5 2020 Marketa Machova <mmachova@suse.com>
- Update to 2.2.1
  * #38: Retry to lock resource if zc.lockfile.LockError is raised.
    Fix needed for pytest-xdist. (StabbarN)
  * #42: Retry on zc.lockfile.LockError in file_lock, use existing
    timeout kwarg (mshriver)
* Mon Jun 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 2.1.0
  * #34: Deprecated slave_id fixture in favor of worker_id,
    for compatibility with pytest-xdist 2.
* Fri Mar 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Feb 24 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in mysql for tests we actually skip anyway
* Fri Nov 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0.1:
  * #23: Rely on zc.lockfile for lockfile behavior.
  * #28: Fixtures now supports later versions of mysql and no longer support versions of mysql prior to mysql --initialize support.
  * #29: Fix issues with later versions of mysql where mysql_defaults_file fixture would prevent startup of mysql.
  * Fixed issue in test suite where mysql fixture was not tested.
  * Removed pytest_services.locks.lock_file.
  * #20: Added workaround for issue with SysLogHandler.
* Tue Mar  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, used by cherrypy
